"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.modifyAngularJsonAndEsLintFile = exports.addAngularESLintPackages = exports.addESLintTargetToProject = exports.createRootESLintConfig = void 0;
const constants_1 = require("./constants");
/**
 * All functions were taken from @angular-eslint/schematics in favour of using eslint.
 * @angular-eslint/schematic provides rules to follow based on the https://angular.io/styleguide:
 *  - plugin:@angular-eslint/recommended
 *  - plugin:@angular-eslint/template/process-inline-templates
 *  - plugin:@angular-eslint/template/recommended
 */
function createRootESLintConfig(prefix) {
    let codeRules = {
        '@angular-eslint/directive-selector': [
            'error',
            { type: 'attribute', prefix, style: 'camelCase' },
        ],
        '@angular-eslint/component-selector': [
            'error',
            { type: 'element', prefix, style: 'kebab-case' },
        ],
    };
    return {
        root: true,
        ignorePatterns: ['projects/**/*'],
        overrides: [
            {
                files: ['*.ts'],
                parserOptions: {
                    project: ['tsconfig.json'],
                    createDefaultProgram: true,
                },
                extends: [
                    'plugin:@angular-eslint/recommended',
                    'plugin:@angular-eslint/template/process-inline-templates',
                ],
                rules: codeRules,
            },
            {
                files: ['*.html'],
                extends: ['plugin:@angular-eslint/template/recommended'],
                rules: {},
            },
        ],
    };
}
exports.createRootESLintConfig = createRootESLintConfig;
function addESLintTargetToProject(angularJson, projectName) {
    const existingProjectConfig = Object.assign({}, angularJson);
    let lintFilePatternsRoot = '';
    // Default Angular CLI project at the root of the workspace
    if (existingProjectConfig.projects[projectName].root === '') {
        lintFilePatternsRoot = 'src';
    }
    else {
        lintFilePatternsRoot = existingProjectConfig.projects[projectName].root;
    }
    existingProjectConfig.cli = (existingProjectConfig === null || existingProjectConfig === void 0 ? void 0 : existingProjectConfig.cli)
        ? existingProjectConfig.cli
        : {};
    existingProjectConfig.cli.defaultCollection = '@angular-eslint/schematics';
    const eslintTargetConfig = {
        builder: '@angular-eslint/builder:lint',
        options: {
            lintFilePatterns: [
                `${lintFilePatternsRoot}/**/*.ts`,
                `${lintFilePatternsRoot}/**/*.html`,
            ],
        },
    };
    existingProjectConfig.projects[projectName].architect['lint'] =
        eslintTargetConfig;
    return existingProjectConfig;
}
exports.addESLintTargetToProject = addESLintTargetToProject;
function addAngularESLintPackages(projectName) {
    return (host, context) => {
        if (!host.exists(`./${projectName}/package.json`)) {
            throw new Error('Could not find a `package.json` file at the root of your workspace');
        }
        if (host.exists(`./${projectName}/tsconfig.base.json`)) {
            throw new Error('\nError: Angular CLI v10.1.0 and later (and no `tsconfig.base.json`) is required in order to run this schematic. Please update your workspace and try again.\n');
        }
        const projectPackageJSON = host.read(`./${projectName}/package.json`).toString('utf-8');
        const json = JSON.parse(projectPackageJSON);
        json.devDependencies = json.devDependencies || {};
        json.devDependencies['eslint'] = '8.x';
        json.scripts = json.scripts || {};
        json.scripts['lint'] = json.scripts['lint'] || 'ng lint';
        // @angular-eslint packages
        json.devDependencies = Object.assign(Object.assign({}, json.devDependencies), constants_1.devDependencies);
        json.devDependencies = sortObjectByKeys(json.devDependencies);
        host.overwrite(`./${projectName}/package.json`, JSON.stringify(json, null, 2));
        context.logger.info(`
All @angular-eslint dependencies have been successfully installed 🎉
Please see https://github.com/angular-eslint/angular-eslint for how to add ESLint configuration to your project.
`);
        return host;
    };
}
exports.addAngularESLintPackages = addAngularESLintPackages;
function modifyAngularJsonAndEsLintFile(projectName) {
    return (host, _context) => {
        const path = `./${projectName}/angular.json`;
        const angularJSON = host.read(path).toString('utf-8');
        const json = JSON.parse(angularJSON);
        const prefix = json.projects[projectName].prefix;
        const eslintConfig = createRootESLintConfig(prefix);
        host.create(`./${projectName}/.eslintrc.json`, JSON.stringify(eslintConfig, null, 2));
        const newAngularJSON = addESLintTargetToProject(json, projectName);
        host.overwrite(path, JSON.stringify(newAngularJSON, null, 2));
        return host;
    };
}
exports.modifyAngularJsonAndEsLintFile = modifyAngularJsonAndEsLintFile;
function sortObjectByKeys(obj) {
    return Object.keys(obj)
        .sort()
        .reduce((result, key) => {
        return Object.assign(Object.assign({}, result), { [key]: obj[key] });
    }, {});
}
//# sourceMappingURL=index.js.map